#
# spec file for package kawaii-player
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines

%define _over   2.8.0-0
%define _bver   2.8.0
Name:           kawaii-player
Version:        2.8.0.0
Release:        lp152.3.3
Summary:        Multimedia player, library manager and media server
License:        GPL-3.0
Group:          Productivity/Multimedia/Video/Players
Url:            https://github.com/kanishka-linux/kawaii-player
Source0:        https://github.com/kanishka-linux/kawaii-player/archive/v%{_over}.tar.gz#/%{name}-%{_over}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
Requires:       ffmpegthumbnailer
Requires:       mpv
Requires:       python3-Pillow
Requires:       python3-base
Requires:       python3-beautifulsoup4
Requires:       python3-libtorrent-rasterbar
Requires:       python3-lxml
Requires:       python3-mutagen
Requires:       python3-pycurl
Requires:       python3-pytaglib
Requires:       python3-qt5
# The one below only until the patched python-qt5 reaches Factory
Requires:       python3-sip
Requires:       python3-youtube-dl
BuildArch:      noarch

%description
Kawaii-Player is an audio/video manager and multimedia player based on mpv
and can also work as media server.

%prep
%setup -q -n %{name}-%{_over}
mv kawaii_player/resources/%{name}.desktop .
sed -e '/^Icon/cIcon = %{name}' -e '/^Exec/cExec = %{name} %f' -e '1{ /^#!/d; }' -i %{name}.desktop
sed -e "s/bs4/beautifulsoup4/g" -e "s/'PyQt5',//g" -i setup.py

%build
python3 setup.py build

%install
python3 setup.py install --root=%{buildroot} --prefix=%{_prefix}
mkdir -pv %{buildroot}/%{_datadir}/applications %{buildroot}/%{_datadir}/pixmaps
install -m 0644 %{name}.desktop %{buildroot}/%{_datadir}/applications/%{name}.desktop
install -m 0644 kawaii_player/resources/tray.png %{buildroot}/%{_datadir}/pixmaps/%{name}.png
%fdupes -s %{buildroot}%{python3_sitelib}

%files
%defattr(-,root,root)
%doc LICENSE README.md
%{_bindir}/%{name}
%{_bindir}/%{name}-console
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/applications/%{name}.desktop
%{python3_sitelib}/kawaii_player
%{python3_sitelib}/kawaii_player-%{_bver}-py%{py3_ver}.egg-info

%changelog
* Thu Nov  9 2017 aloisio@gmx.com
- Update to version 2.8.0-0
  * better handling of fetching episode summary from tvdb
  * allow editing episode summary in summary box
  * summary tooltip added to thumbnail grid
  * keyboard shortcuts added for renaming to default
  * keyboard shortcuts added for fetching episode summary
  * more options added to context menu of playlist
  * separate meta_engine
  * tmdb bug fixed
  * a new command ytq: added, for quick casting of ytdl and
    torrent links from web interface
  * Support added for opening links to ytdl supported sites
  * Internal browser can be used for ytdl supported sites
  * default background image changed
  2.7.0-0
  Web Interface:
  * Code has been adjusted as per server side changes
  * Show/Hide Top Menu Bar bug fixed for mobile browsers.
  * In remote control mode, support for queued items improved,
    achieving better synchronization between web interface and
    desktop interface.
  * Playlist shuffle mode fixed, in remote control mode.
  * Show message on using torrent commands from wrong section
  * New text command clear:cache added for clearing server side
    cache
  Media Server:
  * Implemented server side cache for video, music and playlist
    section for faster fetching.
  * Bug fixed in identifying same titles but different content.
  * Handles queue item remove request in remote control mode
  * Handles clear cache request
  * Allow better synchronization between desktop client and web
    interface in remote control mode
  Desktop client:
  * Thumbnail grid mode made faster, responsive with better zoom
    in/out support.
  * Various bugs fixed in thumbnail grid mode
  * Thumbnail generation in list mode improved without blocking ui.
  * some changes in player stop method to restore state before
    playback
  * Better handling of peer-to-peer mode in thumbnails
  * context menu added to playlist column for renaming file names
    to default.
  * context menu added to playlist for removing thumbnails.
  * bugs fixed in ordering of playlist column in video section
    using page up/down button keys
  * bugs fixed in resizing images
  Other Design Issues:
  * Separate single thumbnail directory for both desktop and web
    interface
  * use of hashing to get thumbnails quickly without querying to
    database, for both desktop client and web interface.
  * In custom playlist, artist can be added manually. Use '::' to
    delimit title from artist when renaming using key F2.
  2.6.1-0
  Web Interface:
  * show torrent status immediately as soon as it is started
  * allow absolute seek from status bar for both remote control
    and client mode
  * allow synchronization as much as possible between web
    interface and remote controlled desktop application
  * changes in get m3u method
  * hide top menu bar properly in mobile interface while scrolling
  * allow m3u generation of playlist history
  * change bottom progress bar properly according to remote
    control on/off state
  Media Server:
  * total_ui_navigation function added for remote controlled mode
  * handle request for force play and pause
  * handle request for absolute seek
  Desktop Interface:
  * crashing of player fixed when server ip address changes
  * thumbnail generation method made responsive
  * allow deleting music library entries
  * reduce time delay between thumbnail generation
  2.6.0-0
  Major changes made in the web interface:
  * Proper context menu support added for both queue and playlists
    for performing multiple operations
  * Legacy menu removed and replaced with Top menu bar
  * Small status bar added to the bottom that will be displayed
    while scrolling long playlist
  * Status bar and Menu bar can both be hidden
  * Thumbnail support added which can be activated using playlist
    context menu
  * Grid layout used for control buttons
  * Bug fixed in torrent streaming within web interface
  * Added buttons for navigating playlist history
  * clear:playlist_history command added, which can be sent using
    search box
  Remote Control mode:
  * Feature added to queue items from web interface for playing on
    kawaii-player server
  Peer to Peer mode:
  * Faster login to peers
  * Better Support for thumbnail display
  * Fetch thumbnails from peers without blocking UI
  Server
  * Server can handle multiple thumbnail image requests
    concurrently
  * Server can remember playlist navigation history for the session
  * Server can remember thumbnail activation mode on web interface
    for the session
  2.5.1-0-beta.1
  * Improved Web Interface
  * Thumbnail support added in both web interface and peer to peer
    mode
  * Context menu added in web interface
  2.5.0-0-beta.3
  * notify broken libtorrent with code 0
  * send_notification function modified
  * qtwebengine related bugs fixed
  * do not update playlist widget for empty list
  * do not allow update values to site_option in serverlib
  * curl globoff by default
  * fullscreen on double click added
  * catch errors in PlayerGetEpn
  * allow mode a+v in get_yt_url
  * 480p quality fixed for yt videos
  * support external audio files properly
  * initialize idw when none
  * some unnecessary variables removed
  * stop arrow timer when active on focussed playlist
  * replace n_art with blank space when none in media_server
  * many bugs related to nt platform fixed
  * signature of ccurl changed
  * fetching of images from last.fm fixed
  * binary for gnu/linux fixed for torrent streaming
  2.4.0-0
  * Allow using mpv input.conf for keyboard shortcuts by setting
    MPV_INPUT_CONF=True in other_options.txt.
  * option to disable aspect ratio
  * log output changed
  * faster login in peer-to-peer mode
  * bugs fixed in getting next file in the playlist when mpv
    doesn't emit EOF code:1
  * Bug fixed in looping file when mpv doesn't emit EOF code:1
  * get external links in addons in asynchronous manner, causing
    major changes in codebase.
  * notify properly when authentication fails in p2p mode
  * allow hierarchy in titlelist
  * allow viewing history in myserver addon
* Sat Sep  2 2017 aloisio@gmx.com
- Fixed version number
* Thu Aug 31 2017 aloisio@gmx.com
- Update to version 2.2.0-1
  * Improved video management functionalities.
  * Allows creating new video categories
  * Allows renaming of title and playlist entries
  * Group rename of playlist entries
  * Improved contextmenu with grouping of various categories
  * Allows getting information for entire collection
  * TMDB support added
  * Supports both duckduckgo and google as search engine backend
    for getting information from either TVDB or TMDB.
  * Keyboard shortcuts have been changed
  * Allows direct jump on title starting with letter when keyboard
    button pertaining to that letter is pressed
  * Firefox related bug fixed when loading subtitles
  * New background image modes with shortcuts (ctrl+0 and ctrl+9)
    added
  * Some image resizing issues fixed with python-pillow
  * Allows using the application as both server as well as client
  * Added new MyServer addon for managing peer-to-peer mode.
  * Servers can broadcast themselves in the local network so that
    clients can discover it without having to remember local IP
    address of each media server.
  * Allows modifying broadcast message of server
  * Users can manually set server's upload speed
  * mpv now remembers last aspect ratio
  * Better OSD display on changing aspect ratio
  * Critical bug fixed in deleting bookmarked playlist
  version 2.0.0-0:
  * Various modules separated and major overhaul of large codebase
  * Headless browser included
  * Proper support added for qtwebkit along with qtwebengine as
    backend for headless browser
  * Multiple bug fixes
* Tue May 23 2017 aloisio@gmx.com
- Fixed source URL
* Sat May 20 2017 aloisio@gmx.com
- Initial package (1.4.0-0)
